@@ -1,9 +1,9 @@
-SUBROUTINE crwdriftn2ll(tau2y, tau2x, sig2, b, bd, sig2d, delta, x, y, loctype, &
+SUBROUTINE crwdriftn2ll(tau2y, tau2x, Qmat, Tmat, x, y, loctype, &
                           stay, ay, ax, Py, Px, lonadj, N, lly, llx)
   INTEGER N
   INTEGER loctype(N), stay(N)
-  DOUBLE PRECISION lly, llx, tau2y(N), tau2x(N)
-  DOUBLE PRECISION sig2(N), b(N), bd(N), sig2d, delta(N), x(N), y(N), lonadj(N)
+  DOUBLE PRECISION lly, llx, tau2y(N), tau2x(N), Qmat(N,5), Tmat(N,4)
+  DOUBLE PRECISION x(N), y(N), lonadj(N)
   DOUBLE PRECISION ay(3,1), ax(3,1), Py(3,3), Px(3,3)
   DOUBLE PRECISION vy, vx, Fy, Fx
   DOUBLE PRECISION Z(1,3)
@@ -28,19 +28,18 @@ SUBROUTINE crwdriftn2ll(tau2y, tau2x, sig2, b, bd, sig2d, delta, x, y, loctype,
       T(1,3) = 0.0
       T(3,3) = 0.0
     ELSE
-      Qy(1,1) = (sig2(i)/(b(i)*b(i)))*(delta(i) - 2*(1-exp(-b(i)*delta(i)))/b(i)  + (1-exp(-2*b(i)*delta(i)))/(2*b(i))) &
-                  + (sig2d/(bd(i)*bd(i)))*(delta(i) - 2*(1-exp(-bd(i)*delta(i)))/bd(i) + (1-exp(-2*bd(i)*delta(i)))/(2*bd(i)))
-      Qy(2,1) = (sig2(i)/(b(i)*b(i)))*((1-2*exp(-b(i)*delta(i))+exp(-2*b(i)*delta(i)))/2)
-      Qy(3,1) = (sig2d/(bd(i)*bd(i)))*((1-2*exp(-bd(i)*delta(i))+exp(-2*bd(i)*delta(i)))/2)
+      Qy(1,1) = Qmat(i,1)
+      Qy(2,1) = Qmat(i,2)
+      Qy(3,1) = Qmat(i,3)
       Qy(1,2) = Qy(2,1)
-      Qy(2,2) = (sig2(i)/b(i))*((1-exp(-2*b(i)*delta(i)))/2)
+      Qy(2,2) = Qmat(i,4)
       Qy(1,3) = Qy(3,1)
-      Qy(3,3) = (sig2d/bd(i))*((1-exp(-2*bd(i)*delta(i)))/2)
+      Qy(3,3) = Qmat(i,5)
       Qx = Qy/(lonadj(i)*lonadj(i))
-      T(1,2) = (1-exp(-b(i)*delta(i)))/b(i)
-      T(2,2) = exp(-b(i)*delta(i))
-      T(1,3) = (1 - exp(-bd(i)*delta(i)))/bd(i)
-      T(3,3) = exp(-bd(i)*delta(i))
+      T(1,2) = Tmat(i,1)
+      T(2,2) = Tmat(i,2)
+      T(1,3) = Tmat(i,3)
+      T(3,3) = Tmat(i,4)
     END IF
 
    !! GENERAL KF LOOP !!
@@ -56,6 +55,7 @@ SUBROUTINE crwdriftn2ll(tau2y, tau2x, sig2, b, bd, sig2d, delta, x, y, loctype,
       Ly = T - MATMUL(Ky,Z)
       ay = MATMUL(T,ay) + Ky*vy
       Py = MATMUL(MATMUL(T,Py),TRANSPOSE(Ly)) + Qy
+
     END IF
     IF(loctype(i)==1 .OR. Fx==0.0) THEN      
       ax = MATMUL(T,ax)
